@@ -35,6 +35,8 @@ __all__ = (
     "ContainerPropertiesTypeDef",
     "ContainerSummaryTypeDef",
     "DeviceTypeDef",
+    "EFSAuthorizationConfigTypeDef",
+    "EFSVolumeConfigurationTypeDef",
     "Ec2ConfigurationTypeDef",
     "EvaluateOnExitTypeDef",
     "FargatePlatformConfigurationTypeDef",
@@ -269,6 +271,33 @@ class DeviceTypeDef(_RequiredDeviceTypeDef, _OptionalDeviceTypeDef):
     pass
 
 
+EFSAuthorizationConfigTypeDef = TypedDict(
+    "EFSAuthorizationConfigTypeDef",
+    {"accessPointId": str, "iam": Literal["ENABLED", "DISABLED"]},
+    total=False,
+)
+
+_RequiredEFSVolumeConfigurationTypeDef = TypedDict(
+    "_RequiredEFSVolumeConfigurationTypeDef", {"fileSystemId": str}
+)
+_OptionalEFSVolumeConfigurationTypeDef = TypedDict(
+    "_OptionalEFSVolumeConfigurationTypeDef",
+    {
+        "rootDirectory": str,
+        "transitEncryption": Literal["ENABLED", "DISABLED"],
+        "transitEncryptionPort": int,
+        "authorizationConfig": "EFSAuthorizationConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class EFSVolumeConfigurationTypeDef(
+    _RequiredEFSVolumeConfigurationTypeDef, _OptionalEFSVolumeConfigurationTypeDef
+):
+    pass
+
+
 _RequiredEc2ConfigurationTypeDef = TypedDict("_RequiredEc2ConfigurationTypeDef", {"imageType": str})
 _OptionalEc2ConfigurationTypeDef = TypedDict(
     "_OptionalEc2ConfigurationTypeDef", {"imageIdOverride": str}, total=False
@@ -541,7 +570,11 @@ class TmpfsTypeDef(_RequiredTmpfsTypeDef, _OptionalTmpfsTypeDef):
 
 UlimitTypeDef = TypedDict("UlimitTypeDef", {"hardLimit": int, "name": str, "softLimit": int})
 
-VolumeTypeDef = TypedDict("VolumeTypeDef", {"host": "HostTypeDef", "name": str}, total=False)
+VolumeTypeDef = TypedDict(
+    "VolumeTypeDef",
+    {"host": "HostTypeDef", "name": str, "efsVolumeConfiguration": "EFSVolumeConfigurationTypeDef"},
+    total=False,
+)
 
 ArrayPropertiesTypeDef = TypedDict("ArrayPropertiesTypeDef", {"size": int}, total=False)
 
